@@ -877,8 +877,9 @@ class Update(object):
                 self._display_error(emerge.prepare_error)
                 raise
             if (self.askConfirm(
-                    _("Would you like to unmerge these packages?")) != 'yes'):
-                return False
+                    _("Would you like to unmerge these unused packages "
+                      "(recommended)?")) != 'yes'):
+                return True
             UpdateInfo(self.clVars).outdated_kernel = outdated_kernel
             self._startEmerging(emerge)
         finally:
